==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/SnmpTrapUI/src/com/clustercontrol/snmptrap/composite/MasterListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmptrap.composite;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerFilter;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.Text;

import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.snmptrap.action.GetMaster;
import com.clustercontrol.snmptrap.action.GetMasterTableDefine;
import com.clustercontrol.snmptrap.bean.MasterTabelDefine;
import com.clustercontrol.snmptrap.bean.MonitorSnmpTrapOidInfo;
import com.clustercontrol.snmptrap.bean.SnmpTrapMasterInfo;
import com.clustercontrol.util.Messages;

/**
 * SNMPTRAPƻޥݥåȥ饹Ǥ
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class MasterListComposite extends Composite {
	public static final int WIDTH_TITLE = 5;
	public static final int WIDTH_VALUE = 2;
	
    // ----- instance ե ----- //

    /** ơ֥ӥ塼 */
    private CommonTableViewer tableViewer = null;
    
    /** ޥ */
    private ArrayList<SnmpTrapMasterInfo> masterList = null;
    
    /** OID */
    private ArrayList<MonitorSnmpTrapOidInfo> oidList = null;

	/** MIB */
	private Combo comboMib = null;
	
	/** ե륿 */
	private Text textFilter = null;
	
    /** ե륿ꥢܥ */
    private Button buttonClearFilter = null;
    
    /** ɽܥ */
    private Button buttonShowTable = null;
    
    // ----- 󥹥ȥ饯 ----- //

    /**
     * 󥹥󥹤֤ޤ
     * 
     * @param parent
     *            ƤΥݥå
     * @param style
     *            
     */
    public MasterListComposite(Composite parent, int style) {
        super(parent, style);

        this.initialize();
    }

    // ----- instance ᥽å ----- //

    /**
     * ݥåȤۤޤ
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;
        layout.numColumns = 15;
        
        //ѿȤѤ٥
		Label label = null;
		
		// 롼
		Group groupFilter = new Group(this, SWT.NONE);
		layout = new GridLayout(1, true);
		layout.marginWidth = 5;
		layout.marginHeight = 5;
		layout.numColumns = 15;
		groupFilter.setLayout(layout);
		GridData gridData = new GridData();
		gridData.horizontalSpan = 15;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		groupFilter.setLayoutData(gridData);
		groupFilter.setText(Messages.getString("filter") + " : ");
		
		/*
		 * MIB
		 */
		// ٥
        label = new Label(groupFilter, SWT.NONE);
        gridData = new GridData();
		gridData.horizontalSpan = WIDTH_TITLE;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("mib") + " : ");
		// ܥܥå
		this.comboMib = new Combo(groupFilter, SWT.DROP_DOWN | SWT.READ_ONLY);
		gridData = new GridData();
		gridData.horizontalSpan = 8;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.comboMib.setLayoutData(gridData);
		this.comboMib.setVisibleItemCount(10);
		// MIBꥹȼ
		ArrayList<String> mibList = new GetMaster().getMibList();
		for(int i = 0; i < mibList.size(); i++){
			this.comboMib.add(mibList.get(i));
		}
		this.comboMib.select(0);
		this.comboMib.addSelectionListener(new SelectionListener(){
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			public void widgetSelected(SelectionEvent e) {
        		//ɽ
        		update();
			}

			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			public void widgetDefaultSelected(SelectionEvent e) {

			}
		});
		// 
		label = new Label(groupFilter, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = 2;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		
		/*
		 * ե륿
		 */
		// ٥
		label = new Label(groupFilter, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_TITLE;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("trap.name") + " : ");
		// ƥ
		this.textFilter = new Text(groupFilter, SWT.BORDER | SWT.LEFT);
		gridData = new GridData();
		gridData.horizontalSpan = 6;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.textFilter.setLayoutData(gridData);
        // ꥢܥ
        this.buttonClearFilter = new Button(groupFilter, SWT.NONE);
        this.buttonClearFilter.setText(Messages.getString("clear"));
		gridData = new GridData();
		gridData.horizontalSpan = 2;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.buttonClearFilter.setLayoutData(gridData);
        this.buttonClearFilter.addSelectionListener(new SelectionAdapter() {
        	public void widgetSelected(SelectionEvent e) {
        		textFilter.setText("");
        	}
        });
        // ɽܥ
        this.buttonShowTable = new Button(groupFilter, SWT.NONE);
        this.buttonShowTable.setText(Messages.getString("show"));
		gridData = new GridData();
		gridData.horizontalSpan = 2;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.buttonShowTable.setLayoutData(gridData);
        this.buttonShowTable.addSelectionListener(new SelectionAdapter() {
        	public void widgetSelected(SelectionEvent e) {
        		//ɽ
        		update();
        	}
        });
        
        Table table = new Table(this, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.BORDER);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        gridData = new GridData();
		gridData.horizontalSpan = 15;
		gridData.minimumHeight = 200;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
        table.setLayoutData(gridData);
        
        // ơ֥ӥ塼κ
        this.tableViewer = new CommonTableViewer(table);
        this.tableViewer.createTableColumn(GetMasterTableDefine.get(),
        		MasterTabelDefine.SORT_COLUMN_INDEX,
        		MasterTabelDefine.SORT_ORDER);

        this.update();
    }

    /**
     * tableViewer֤ޤ
     * 
     * @return tableViewer
     */
    public CommonTableViewer getTableViewer() {
        return this.tableViewer;
    }

	/**
     * ݥåȤ򹹿ޤ
     * <p>
     * 
     */
    public void update() {
    	
		//ޥ
    	this.masterList = new GetMaster().getMasterList(comboMib.getText());
    	
    	ArrayList list = collectionToArray(this.masterList);
    	
    	//ե륿
    	this.tableViewer.addFilter(new ViewerFilter(){
    		
    		/* (non-Javadoc)
    		 * @see org.eclipse.jface.viewers.ViewerFilter#select(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
    		 */
    		@Override
    		public boolean select(Viewer viewer, Object parentElement, Object element) {
    			boolean select = true;
    			
    			ArrayList info = (ArrayList)element;
    			
    			String mib = (String)info.get(MasterTabelDefine.MIB);
    			String trapName = (String)info.get(MasterTabelDefine.TRAP_NAME);
    			
    			if(oidList != null){
    				String trapOid = (String)info.get(MasterTabelDefine.TRAP_OID);
        			Integer genericId = (Integer)info.get(MasterTabelDefine.GENERIC_ID);
        			Integer specificId = (Integer)info.get(MasterTabelDefine.SPECIFIC_ID);
        			
	    			for(int i = 0 ; i < oidList.size(); i++){
	    				MonitorSnmpTrapOidInfo oidInfo = oidList.get(i);
	    				if(mib.equals(oidInfo.getMib()) && 
	    						trapOid.equals(oidInfo.getTrapOid()) && 
	    						genericId.equals(oidInfo.getGenericId()) && 
	    						specificId.equals(oidInfo.getSpecificId())){
	    					select = false;
	    				}
	    			}
    			}
    			
    			if(!comboMib.getText().equals("")){
    				if(!mib.equals(comboMib.getText())){
    					select = false;
    				}
    			}
    			
    			if(!textFilter.getText().equals("")){
    				if(!trapName.matches(textFilter.getText())){
    					select = false;
    				}
    			}
    			
    			return select;
    		}
    	});
    	
        // ơ֥빹
        this.tableViewer.setInput(list);
    }
    
	/**
	 * 򤷤ޥ
	 * 
	 * @return 
	 */
	public ArrayList<SnmpTrapMasterInfo> getSelectMaster() {
		
		ArrayList<SnmpTrapMasterInfo> data = new ArrayList<SnmpTrapMasterInfo>();
		
		//򤵤줿ƥ
		StructuredSelection selection = 
			(StructuredSelection)tableViewer.getSelection();
		List list = (List)selection.toList();
		
		if (list != null) {
			for(int index = 0; index < list.size(); index++){
				
				ArrayList info = (ArrayList)list.get(index);
				if (info != null && info.size() > 0) {
					String mib = (String)info.get(MasterTabelDefine.MIB);
					String oid = (String)info.get(MasterTabelDefine.TRAP_OID);
					Integer genericId = (Integer)info.get(MasterTabelDefine.GENERIC_ID);
					Integer specificId = (Integer)info.get(MasterTabelDefine.SPECIFIC_ID);
					
					if (this.masterList != null) {
						for(int i = 0; i < this.masterList.size(); i++){
							SnmpTrapMasterInfo master = this.masterList.get(i);
							
							if(mib.equals(master.getMib()) && 
									oid.equals(master.getTrapOid()) && 
									genericId.equals(master.getGenericId()) && 
									specificId.equals(master.getSpecificId())){
								
								data.add(master);
								break;
							}
						}
					}
				}
			}
		}
		
		return data;
	}
    
	/**
	 * ޥObject2˳Ǽ
	 * 
	 * @param masterList
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public ArrayList collectionToArray(ArrayList<SnmpTrapMasterInfo> masterList) {
		
		ArrayList list = new ArrayList();
		if(masterList != null){
			Iterator itr = masterList.iterator();
			while(itr.hasNext())
			{
				SnmpTrapMasterInfo master = (SnmpTrapMasterInfo)itr.next();
	
				ArrayList info = new ArrayList();
				info.add(master.getMib());
				info.add(master.getUei());
				info.add(master.getTrapOid());
				info.add(new Integer(master.getGenericId()));
				info.add(new Integer(master.getSpecificId()));
				info.add(new Integer(master.getPriority()));
				info.add(master.getLogmsg());
				list.add(info);
			}
		}
		return list;
	}

	/**
	 * @return
	 */
	public ArrayList<MonitorSnmpTrapOidInfo> getOidList() {
		return oidList;
	}

	/**
	 * @param oidList
	 */
	public void setOidList(ArrayList<MonitorSnmpTrapOidInfo> oidList) {
		this.oidList = oidList;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/SnmpTrapUI/src/com/clustercontrol/snmptrap/composite/MasterListComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmptrap.composite;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerFilter;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.Text;

import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.snmptrap.action.GetMaster;
import com.clustercontrol.snmptrap.action.GetMasterTableDefine;
import com.clustercontrol.snmptrap.bean.MasterTabelDefine;
import com.clustercontrol.snmptrap.bean.MonitorSnmpTrapOidInfo;
import com.clustercontrol.snmptrap.bean.SnmpTrapMasterInfo;
import com.clustercontrol.util.Messages;

/**
 * SNMPTRAP監視マスタ一覧コンポジットクラスです。
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class MasterListComposite extends Composite {
	public static final int WIDTH_TITLE = 5;
	public static final int WIDTH_VALUE = 2;
	
    // ----- instance フィールド ----- //

    /** テーブルビューア */
    private CommonTableViewer tableViewer = null;
    
    /** マスタ情報 */
    private ArrayList<SnmpTrapMasterInfo> masterList = null;
    
    /** OID情報 */
    private ArrayList<MonitorSnmpTrapOidInfo> oidList = null;

	/** MIB */
	private Combo comboMib = null;
	
	/** フィルタ */
	private Text textFilter = null;
	
    /** フィルタクリアボタン */
    private Button buttonClearFilter = null;
    
    /** 表示ボタン */
    private Button buttonShowTable = null;
    
    // ----- コンストラクタ ----- //

    /**
     * インスタンスを返します。
     * 
     * @param parent
     *            親のコンポジット
     * @param style
     *            スタイル
     */
    public MasterListComposite(Composite parent, int style) {
        super(parent, style);

        this.initialize();
    }

    // ----- instance メソッド ----- //

    /**
     * コンポジットを生成・構築します。
     */
    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;
        layout.numColumns = 15;
        
        //変数として利用されるラベル
		Label label = null;
		
		// グループ
		Group groupFilter = new Group(this, SWT.NONE);
		layout = new GridLayout(1, true);
		layout.marginWidth = 5;
		layout.marginHeight = 5;
		layout.numColumns = 15;
		groupFilter.setLayout(layout);
		GridData gridData = new GridData();
		gridData.horizontalSpan = 15;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		groupFilter.setLayoutData(gridData);
		groupFilter.setText(Messages.getString("filter") + " : ");
		
		/*
		 * MIB
		 */
		// ラベル
        label = new Label(groupFilter, SWT.NONE);
        gridData = new GridData();
		gridData.horizontalSpan = WIDTH_TITLE;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("mib") + " : ");
		// コンボボックス
		this.comboMib = new Combo(groupFilter, SWT.DROP_DOWN | SWT.READ_ONLY);
		gridData = new GridData();
		gridData.horizontalSpan = 8;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.comboMib.setLayoutData(gridData);
		this.comboMib.setVisibleItemCount(10);
		// MIBリスト取得
		ArrayList<String> mibList = new GetMaster().getMibList();
		for(int i = 0; i < mibList.size(); i++){
			this.comboMib.add(mibList.get(i));
		}
		this.comboMib.select(0);
		this.comboMib.addSelectionListener(new SelectionListener(){
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			public void widgetSelected(SelectionEvent e) {
        		//表示処理
        		update();
			}

			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			public void widgetDefaultSelected(SelectionEvent e) {

			}
		});
		// 空白
		label = new Label(groupFilter, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = 2;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		
		/*
		 * フィルタ
		 */
		// ラベル
		label = new Label(groupFilter, SWT.NONE);
		gridData = new GridData();
		gridData.horizontalSpan = WIDTH_TITLE;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		label.setLayoutData(gridData);
		label.setText(Messages.getString("trap.name") + " : ");
		// テキスト
		this.textFilter = new Text(groupFilter, SWT.BORDER | SWT.LEFT);
		gridData = new GridData();
		gridData.horizontalSpan = 6;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.textFilter.setLayoutData(gridData);
        // クリアボタン
        this.buttonClearFilter = new Button(groupFilter, SWT.NONE);
        this.buttonClearFilter.setText(Messages.getString("clear"));
		gridData = new GridData();
		gridData.horizontalSpan = 2;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.buttonClearFilter.setLayoutData(gridData);
        this.buttonClearFilter.addSelectionListener(new SelectionAdapter() {
        	public void widgetSelected(SelectionEvent e) {
        		textFilter.setText("");
        	}
        });
        // 表示ボタン
        this.buttonShowTable = new Button(groupFilter, SWT.NONE);
        this.buttonShowTable.setText(Messages.getString("show"));
		gridData = new GridData();
		gridData.horizontalSpan = 2;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		this.buttonShowTable.setLayoutData(gridData);
        this.buttonShowTable.addSelectionListener(new SelectionAdapter() {
        	public void widgetSelected(SelectionEvent e) {
        		//表示処理
        		update();
        	}
        });
        
        Table table = new Table(this, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.BORDER);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        gridData = new GridData();
		gridData.horizontalSpan = 15;
		gridData.minimumHeight = 200;
		gridData.horizontalAlignment = GridData.FILL;
		gridData.verticalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
        table.setLayoutData(gridData);
        
        // テーブルビューアの作成
        this.tableViewer = new CommonTableViewer(table);
        this.tableViewer.createTableColumn(GetMasterTableDefine.get(),
        		MasterTabelDefine.SORT_COLUMN_INDEX,
        		MasterTabelDefine.SORT_ORDER);

        this.update();
    }

    /**
     * tableViewerを返します。
     * 
     * @return tableViewer
     */
    public CommonTableViewer getTableViewer() {
        return this.tableViewer;
    }

	/**
     * コンポジットを更新します。
     * <p>
     * 
     */
    public void update() {
    	
		//マスタ一覧情報を取得
    	this.masterList = new GetMaster().getMasterList(comboMib.getText());
    	
    	ArrayList list = collectionToArray(this.masterList);
    	
    	//フィルタを設定
    	this.tableViewer.addFilter(new ViewerFilter(){
    		
    		/* (non-Javadoc)
    		 * @see org.eclipse.jface.viewers.ViewerFilter#select(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
    		 */
    		@Override
    		public boolean select(Viewer viewer, Object parentElement, Object element) {
    			boolean select = true;
    			
    			ArrayList info = (ArrayList)element;
    			
    			String mib = (String)info.get(MasterTabelDefine.MIB);
    			String trapName = (String)info.get(MasterTabelDefine.TRAP_NAME);
    			
    			if(oidList != null){
    				String trapOid = (String)info.get(MasterTabelDefine.TRAP_OID);
        			Integer genericId = (Integer)info.get(MasterTabelDefine.GENERIC_ID);
        			Integer specificId = (Integer)info.get(MasterTabelDefine.SPECIFIC_ID);
        			
	    			for(int i = 0 ; i < oidList.size(); i++){
	    				MonitorSnmpTrapOidInfo oidInfo = oidList.get(i);
	    				if(mib.equals(oidInfo.getMib()) && 
	    						trapOid.equals(oidInfo.getTrapOid()) && 
	    						genericId.equals(oidInfo.getGenericId()) && 
	    						specificId.equals(oidInfo.getSpecificId())){
	    					select = false;
	    				}
	    			}
    			}
    			
    			if(!comboMib.getText().equals("")){
    				if(!mib.equals(comboMib.getText())){
    					select = false;
    				}
    			}
    			
    			if(!textFilter.getText().equals("")){
    				if(!trapName.matches(textFilter.getText())){
    					select = false;
    				}
    			}
    			
    			return select;
    		}
    	});
    	
        // テーブル更新
        this.tableViewer.setInput(list);
    }
    
	/**
	 * 選択したマスタ情報を取得
	 * 
	 * @return 
	 */
	public ArrayList<SnmpTrapMasterInfo> getSelectMaster() {
		
		ArrayList<SnmpTrapMasterInfo> data = new ArrayList<SnmpTrapMasterInfo>();
		
		//選択されたアイテムを取得
		StructuredSelection selection = 
			(StructuredSelection)tableViewer.getSelection();
		List list = (List)selection.toList();
		
		if (list != null) {
			for(int index = 0; index < list.size(); index++){
				
				ArrayList info = (ArrayList)list.get(index);
				if (info != null && info.size() > 0) {
					String mib = (String)info.get(MasterTabelDefine.MIB);
					String oid = (String)info.get(MasterTabelDefine.TRAP_OID);
					Integer genericId = (Integer)info.get(MasterTabelDefine.GENERIC_ID);
					Integer specificId = (Integer)info.get(MasterTabelDefine.SPECIFIC_ID);
					
					if (this.masterList != null) {
						for(int i = 0; i < this.masterList.size(); i++){
							SnmpTrapMasterInfo master = this.masterList.get(i);
							
							if(mib.equals(master.getMib()) && 
									oid.equals(master.getTrapOid()) && 
									genericId.equals(master.getGenericId()) && 
									specificId.equals(master.getSpecificId())){
								
								data.add(master);
								break;
							}
						}
					}
				}
			}
		}
		
		return data;
	}
    
	/**
	 * マスタ情報をObjectの2次元配列に格納
	 * 
	 * @param masterList
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public ArrayList collectionToArray(ArrayList<SnmpTrapMasterInfo> masterList) {
		
		ArrayList list = new ArrayList();
		if(masterList != null){
			Iterator itr = masterList.iterator();
			while(itr.hasNext())
			{
				SnmpTrapMasterInfo master = (SnmpTrapMasterInfo)itr.next();
	
				ArrayList info = new ArrayList();
				info.add(master.getMib());
				info.add(master.getUei());
				info.add(master.getTrapOid());
				info.add(new Integer(master.getGenericId()));
				info.add(new Integer(master.getSpecificId()));
				info.add(new Integer(master.getPriority()));
				info.add(master.getLogmsg());
				list.add(info);
			}
		}
		return list;
	}

	/**
	 * @return
	 */
	public ArrayList<MonitorSnmpTrapOidInfo> getOidList() {
		return oidList;
	}

	/**
	 * @param oidList
	 */
	public void setOidList(ArrayList<MonitorSnmpTrapOidInfo> oidList) {
		this.oidList = oidList;
	}
}
